==> springdoc-openapi-starter-common-2.8.13-sources.jar: org/springdoc/scalar/ScalarConstants.java <==
/*
 *
 *  *
 *  *  *
 *  *  *  *
 *  *  *  *  *
 *  *  *  *  *  * Copyright 2019-2025 the original author or authors.
 *  *  *  *  *  *
 *  *  *  *  *  * Licensed under the Apache License, Version 2.0 (the "License");
 *  *  *  *  *  * you may not use this file except in compliance with the License.
 *  *  *  *  *  * You may obtain a copy of the License at
 *  *  *  *  *  *
 *  *  *  *  *  *      https://www.apache.org/licenses/LICENSE-2.0
 *  *  *  *  *  *
 *  *  *  *  *  * Unless required by applicable law or agreed to in writing, software
 *  *  *  *  *  * distributed under the License is distributed on an "AS IS" BASIS,
 *  *  *  *  *  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  *  *  *  *  * See the License for the specific language governing permissions and
 *  *  *  *  *  * limitations under the License.
 *  *  *  *  *
 *  *  *  *
 *  *  *
 *  *
 *
 */

package org.springdoc.scalar;

/**
 * The type ScalarConstants.
 *
 * @author bnasslahsen
 */
public class ScalarConstants {

	/**
	 * The constant SCALAR_DEFAULT_PATH.
	 */
	public static final String SCALAR_DEFAULT_PATH = "/scalar";

	/**
	 * The constant SCALAR_JS_FILENAME.
	 */
	public static final String SCALAR_JS_FILENAME = "scalar.js";

	/**
	 * The constant SCALAR_DEFAULT_URL.
	 */
	public static final String SCALAR_DEFAULT_URL = "https://cdn.jsdelivr.net/npm/@scalar/galaxy/dist/latest.json";

	/**
	 * The constant DEFAULT_SCALAR_ACTUATOR_PATH.
	 */
	public static final String DEFAULT_SCALAR_ACTUATOR_PATH = "scalar";
}

==> springdoc-openapi-starter-common-2.8.14-sources.jar: org/springdoc/scalar/ScalarConstants.java <==
/*
 *
 *  *
 *  *  *
 *  *  *  *
 *  *  *  *  *
 *  *  *  *  *  * Copyright 2019-2025 the original author or authors.
 *  *  *  *  *  *
 *  *  *  *  *  * Licensed under the Apache License, Version 2.0 (the "License");
 *  *  *  *  *  * you may not use this file except in compliance with the License.
 *  *  *  *  *  * You may obtain a copy of the License at
 *  *  *  *  *  *
 *  *  *  *  *  *      https://www.apache.org/licenses/LICENSE-2.0
 *  *  *  *  *  *
 *  *  *  *  *  * Unless required by applicable law or agreed to in writing, software
 *  *  *  *  *  * distributed under the License is distributed on an "AS IS" BASIS,
 *  *  *  *  *  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  *  *  *  *  * See the License for the specific language governing permissions and
 *  *  *  *  *  * limitations under the License.
 *  *  *  *  *
 *  *  *  *
 *  *  *
 *  *
 *
 */

package org.springdoc.scalar;

/**
 * The type ScalarConstants.
 *
 * @author bnasslahsen
 */
public class ScalarConstants {

	/**
	 * The constant SCALAR_DEFAULT_PATH.
	 */
	public static final String SCALAR_DEFAULT_PATH = "/scalar";

	/**
	 * The constant SCALAR_JS_FILENAME.
	 */
	public static final String SCALAR_JS_FILENAME = "scalar.js";

	/**
	 * The constant SCALAR_DEFAULT_URL.
	 */
	public static final String SCALAR_DEFAULT_URL = "https://registry.scalar.com/@scalar/apis/galaxy/latest?format=json";

	/**
	 * The constant DEFAULT_SCALAR_ACTUATOR_PATH.
	 */
	public static final String DEFAULT_SCALAR_ACTUATOR_PATH = "scalar";
}
